%monthlymean ver0.10a XV20131020
function monthlymean

format_f='config/format.txt';
outputmean_f='monthly_mean_exam.csv';
outputsdv_f='monthly_std_exam.csv';

prompt = 'year(yyyy)?';
yr=input(prompt);

prompt = 'month(mm)? ';
mn=input(prompt);

[imax,jmax,variablename,dir_input_f,dir_output_f]=read_configfile(format_f);

% calculate daily mean

m=zeros(imax,jmax);
num_grid=zeros(imax,jmax);

for dy=1:31
    for hr=0:23
        for min=0:59

            ut=jst2utc(yr,mn,dy,hr,min,0);
            examfile=make_filename(ut,variablename,dir_input_f);

            if exist(examfile) == 2
                fprintf('%s\n',examfile);
                fid_inputfile=fopen(examfile,'r','b');
                pickup=fread(fid_inputfile,[imax,jmax],'single');
                for grdj=1:jmax
                    for grdi=1:imax
                        num_grid(grdi,grdj)=num_grid(grdi,grdj)+1;
                        m(grdi,grdj)=m(grdi,grdj)+pickup(grdi,grdj);
                    end
                end
                fclose(fid_inputfile);
            end
        end
    end
end

fid_output=fopen(strcat(dir_output_f,outputmean_f),'w');

for grdj=1:jmax
    for grdi=1:imax-1
        m(grdi,grdj)=m(grdi,grdj)/num_grid(grdi,grdj);
        fprintf(fid_output,'%8.3f,',m(grdi,grdj));
    end

    grdi=imax;
    m(grdi,grdj)=m(grdi,grdj)/num_grid(grdi,grdj);
    fprintf(fid_output,'%8.3f\n',m(grdi,grdj));
end 

fclose(fid_output);

% calculate standard deviation

sd=zeros(imax,jmax);

for dy=1:31
    for hr=0:23
        for min=0:59
            
            ut=jst2utc(yr,mn,dy,hr,min,0);
            examfile=make_filename(ut,variablename,dir_input_f);

            if exist(examfile) == 2

               fprintf('%s\n',examfile);
               fid_inputfile=fopen(examfile,'r','b');
               pickup=fread(fid_inputfile,[imax,jmax],'single');

                for grdj=1:jmax
                    for grdi=1:imax
                        sd(grdi,grdj)=sd(grdi,grdj)+(pickup(grdi,grdj)-m(grdi,grdj))^2;
                    end
                end
            
                fclose(fid_inputfile);
            end
        end
    end
end

fid_output=fopen(strcat(dir_output_f,outputsdv_f),'w');

for grdj=1:jmax
    for grdi=1:imax-1
        sd(grdi,grdj)=sqrt(sd(grdi,grdj)/num_grid(grdi,grdj));
        fprintf(fid_output,'%8.3f,',sd(grdi,grdj));
    end

    grdi=imax;
    sd(grdi,grdj)=sqrt(sd(grdi,grdj)/num_grid(grdi,grdj));
    fprintf(fid_output,'%8.3f\n',sd(grdi,grdj));

end 

fclose(fid_output);
end

function ut=jst2utc(yr,mn,dy,hr,min,sec)

t_zone=9;

t = datenum(yr,mn,dy,hr,min,sec);

%fprintf('JST %s\n',datestr(t));

ut= addtodate(t, -1*t_zone, 'hour');

%fprintf('UTC %s\n',datestr(ut));
end

function [imax,jmax,variablename,dir_input_f,dir_output_f]=read_configfile(format_f)

fid_config=fopen(format_f,'r');

cline = fgetl(fid_config);
c = strsplit(cline);
cimax=c{1};
imax=str2num(cimax);
fprintf('%u\n',imax);

cline = fgetl(fid_config);
c = strsplit(cline);
cjmax=c{1};
jmax=str2num(cjmax);
fprintf('%u\n',jmax);

cline = fgetl(fid_config);
c = strsplit(cline);
variablename=c{1};
fprintf('%s\n',variablename);

cline = fgetl(fid_config);
c = strsplit(cline);
dir_input_f=c{1};
fprintf('%s\n',dir_input_f);

for i=1:2
    cline = fgetl(fid_config);
end

cline = fgetl(fid_config);
c = strsplit(cline);
dir_output_f=c{1};
fprintf('%s\n',dir_output_f);

fclose(fid_config);
end

function filename=make_filename(ut,variablename,dir_input_f)

vecut = datevec(ut);

yr=int2str(vecut(1));

if vecut(2) >=10
    mon=int2str(vecut(2));
else
    mon=strcat('0',int2str(vecut(2)));
end

if vecut(3) >=10
    dy=int2str(vecut(3));
else
    dy=strcat('0',int2str(vecut(3)));
end

if vecut(4) >=10
    hr=int2str(vecut(4));
else
    hr=strcat('0',int2str(vecut(4)));
end

if vecut(5) >=10
    min=int2str(vecut(5));
else
    min=strcat('0',int2str(vecut(5)));
end

if vecut(6) >=10
    sc=int2str(vecut(6));
else
    sc=strcat('0',int2str(vecut(6)));
end

cyr=strcat(yr,mon,dy,hr,min);

filename=strcat(dir_input_f,cyr,variablename,'.bin');
%fprintf('%s\n',filename);
end